==> haskell-profunctors-5.6.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 profunctors
version:              5.6.3
visibility:           public
id:                   profunctors-5.6.3-HkDOXx1Uj3cE0VHbxKtxGH
key:                  profunctors-5.6.3-HkDOXx1Uj3cE0VHbxKtxGH
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  990c74df6fa9fced5ca3f1b07248e4f9
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-profunctors
hs-libraries:         HSprofunctors-5.6.3-HkDOXx1Uj3cE0VHbxKtxGH
depends:
    base-4.17.2.1 base-orphans-0.9.2-G8NubFRK2VB2Dy4t4WPIUw
    bifunctors-5.6.1-LfpqHZxWXAbEzwimmPLIG8
    comonad-5.0.9-DcjlGJ2nFITBh9RczgN9OW
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-JWrRvxW4M5uLlDVH9ni0Nb
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.6.3-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 profunctors
version:              5.6.3
visibility:           public
id:                   profunctors-5.6.3-HEYfd0vfOhiGNfrAjjmycl
key:                  profunctors-5.6.3-HEYfd0vfOhiGNfrAjjmycl
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  79241ad5dc4d80ad7244e3477c32fb74
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-profunctors
hs-libraries:         HSprofunctors-5.6.3-HEYfd0vfOhiGNfrAjjmycl
depends:
    base-4.17.2.1 base-orphans-0.9.2-LcLfqlhuMUyAggTt82VG9A
    bifunctors-5.6.1-93Wvyjcd6mp2SgVZWl0gd9
    comonad-5.0.9-DPxzWzHLu9J4KqNMUV0jwa
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-5k32WwedWHTJdotUZFNuHG
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
